@@ -1,4 +1,5 @@
 import requests
+from datetime import date, timedelta
 import time
 from pprint import pprint
 import json
@@ -9,7 +10,7 @@ RESULT_URL = 'https://informationtracer.com/api/v1/result'
 JOB_STATUS_URL = 'https://informationtracer.com/job_status'
 
 def trace(query=None, skip_result=False, result_filename=None, 
-    timeout=240, verbose=True, token=None):
+    timeout=240, verbose=True, token=None, start_date=None, end_date=None):
     """
         Submit a query, wait for the job to finish, and collect the results
         
@@ -19,9 +20,23 @@ def trace(query=None, skip_result=False, result_filename=None,
         print('query cannot be none')
         return
 
+    # by default, start_date is 7 days ago, end_date is today+1
+    collect_date=date.today()
+
+    if start_date is None:
+        start_date = collect_date - timedelta(days=7)
+        start_date = str(start_date)    
+
+    if end_date is None:
+        end_date = collect_date + timedelta(days=1)
+        end_date = str(end_date)
+
     response = requests.post(TRACE_URL, 
-                             json={'term': query, 
-                                   'token': token}
+                             json={'query': query, 
+                                   'token': token,
+                                   'start_date': start_date,
+                                   'end_date': end_date
+                                   }                                   
                                    )
     
     pprint(response.json())
@@ -93,6 +108,8 @@ if __name__ == '__main__':
     import argparse
     parser = argparse.ArgumentParser(description='search parameters.')
     parser.add_argument('--query', type=str, default=None, help='search string')
+    parser.add_argument('--start_date', type=str, default=None, help='earlist post, format YYYY-MM-DD')
+    parser.add_argument('--end_date', type=str, default=None, help='latest post, format YYYY-MM-DD')
     parser.add_argument('--token', type=str, required=True, help='API token')
     parser.add_argument('--skip_result', action='store_true', default=False, required=False, help='if exists, skip collecting results')
     parser.add_argument('--timeout', type=int, default=240)
@@ -106,6 +123,8 @@ if __name__ == '__main__':
 
     trace(query=args.query,
         token=args.token,
+        start_date=args.start_date,
+        end_date=args.end_date,
         timeout=args.timeout,
         skip_result=args.skip_result,
         result_filename=args.result_filename)
